# GPT3Prompts Generator for AI Art

This is a Python package for easy to generator prompts text for ai art from GPT-3 
which performs a wide variety of natural language tasks,and created any prompts 
it is very useful for create any portraits 
## Installation

```
pip install GPT3Prompts==0.0.3
or in colab google cloud
!pip install GPT3Prompts==0.0.3

```

## Tutorial
```
from gpt3prompts import prompts as gen  #import modules
user_input = "CLAUDE MONET"   # input style name
input_object = "female"  #input object 
API_KEY = 'XXX-XXXXXXXXXXU2y5b4T3BlbkFJXXXXXXX' # input API_KEY
gen.generation(user_input,input_object,API_KEY)

```

[Colab Google Drive](https://colab.research.google.com/drive/1-LW1MAWD3w8Zb-PwZ_P-ESBDvrG_mK-L?usp=sharing)
```
u can see tutorial in colab google drive

```
